Method: GithubPivotalFlow::Command#initialize

Defined in:
lib/github_pivotal_flow/command.rb

#initialize(*args) ⇒ Command

Common initialization functionality for all command classes. This enforces that:

  • the command is being run within a valid Git repository

  • the user has specified their Pivotal Tracker API token

  • all communication with Pivotal Tracker will be protected with SSL

  • the user has configured the project id for this repository



14
15
16
17
18
19
20
21
22
# File 'lib/github_pivotal_flow/command.rb', line 14

def initialize(*args)
  @options = {}
  args = parse_argv(*args)
  @options[:args] = args
  @configuration = Configuration.new(@options)
  # Validate the configuration to make sure everything is set up correctly
  @configuration.validate
  @project = @configuration.project
end